---
title: <span class="badge builder"></span> ElasticsearchGeoHashGridSettings
---
# <span class="badge builder"></span> ElasticsearchGeoHashGridSettings

## Constructor

```python
ElasticsearchGeoHashGridSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.ElasticsearchGeoHashGridSettings
```

### <span class="badge object-method"></span> precision

```python
def precision(precision: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [ElasticsearchGeoHashGridSettings](./object-ElasticsearchGeoHashGridSettings.md)
